"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.device_network_api import DeviceNetworkApi  # noqa: E501


class TestDeviceNetworkApi(unittest.TestCase):
    """DeviceNetworkApi unit test stubs"""

    def setUp(self):
        self.api = DeviceNetworkApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_network_issues_summary(self):
        """Test case for get_network_issues_summary

        """
        pass

    def test_get_network_status_summary(self):
        """Test case for get_network_status_summary

        """
        pass

    def test_get_reboot_count(self):
        """Test case for get_reboot_count

        """
        pass

    def test_get_vmanage_control_status(self):
        """Test case for get_vmanage_control_status

        """
        pass


if __name__ == '__main__':
    unittest.main()
