"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.troubleshooting_tools_device_group_api import TroubleshootingToolsDeviceGroupApi  # noqa: E501


class TestTroubleshootingToolsDeviceGroupApi(unittest.TestCase):
    """TroubleshootingToolsDeviceGroupApi unit test stubs"""

    def setUp(self):
        self.api = TroubleshootingToolsDeviceGroupApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_list_device_group_list(self):
        """Test case for list_device_group_list

        """
        pass

    def test_list_device_groups(self):
        """Test case for list_device_groups

        """
        pass

    def test_list_group_devices(self):
        """Test case for list_group_devices

        """
        pass

    def test_list_group_devices_for_map(self):
        """Test case for list_group_devices_for_map

        """
        pass

    def test_list_group_links_for_map(self):
        """Test case for list_group_links_for_map

        """
        pass


if __name__ == '__main__':
    unittest.main()
