"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.configuration_device_software_package_api import ConfigurationDeviceSoftwarePackageApi  # noqa: E501


class TestConfigurationDeviceSoftwarePackageApi(unittest.TestCase):
    """ConfigurationDeviceSoftwarePackageApi unit test stubs"""

    def setUp(self):
        self.api = ConfigurationDeviceSoftwarePackageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_vnf_package(self):
        """Test case for create_vnf_package

        """
        pass

    def test_edit_config_file(self):
        """Test case for edit_config_file

        """
        pass

    def test_get_file_contents(self):
        """Test case for get_file_contents

        """
        pass

    def test_upload_image_file(self):
        """Test case for upload_image_file

        """
        pass


if __name__ == '__main__':
    unittest.main()
