"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_dpion_demand_troubleshooting_api import MonitoringDPIOnDemandTroubleshootingApi  # noqa: E501


class TestMonitoringDPIOnDemandTroubleshootingApi(unittest.TestCase):
    """MonitoringDPIOnDemandTroubleshootingApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringDPIOnDemandTroubleshootingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_queue_entry(self):
        """Test case for create_queue_entry

        """
        pass

    def test_delete_queue_entry(self):
        """Test case for delete_queue_entry

        """
        pass

    def test_get_queue_entries(self):
        """Test case for get_queue_entries

        """
        pass

    def test_get_queue_properties(self):
        """Test case for get_queue_properties

        """
        pass

    def test_update_queue_entry(self):
        """Test case for update_queue_entry

        """
        pass


if __name__ == '__main__':
    unittest.main()
