"""
    Cisco SD-WAN vManage API

    The vManage API exposes the functionality of operations maintaining devices and the overlay network  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: vmanage@cisco.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import openapi_client
from openapi_client.api.monitoring_url_filtering_api import MonitoringURLFilteringApi  # noqa: E501


class TestMonitoringURLFilteringApi(unittest.TestCase):
    """MonitoringURLFilteringApi unit test stubs"""

    def setUp(self):
        self.api = MonitoringURLFilteringApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_aggregation_data_by_query22(self):
        """Test case for get_aggregation_data_by_query22

        """
        pass

    def test_get_count24(self):
        """Test case for get_count24

        """
        pass

    def test_get_count_post24(self):
        """Test case for get_count_post24

        """
        pass

    def test_get_post_aggregation_app_data_by_query21(self):
        """Test case for get_post_aggregation_app_data_by_query21

        """
        pass

    def test_get_post_aggregation_data_by_query21(self):
        """Test case for get_post_aggregation_data_by_query21

        """
        pass

    def test_get_post_stat_bulk_raw_data22(self):
        """Test case for get_post_stat_bulk_raw_data22

        """
        pass

    def test_get_stat_bulk_raw_data22(self):
        """Test case for get_stat_bulk_raw_data22

        """
        pass

    def test_get_stat_data_fields24(self):
        """Test case for get_stat_data_fields24

        """
        pass

    def test_get_stat_data_raw_data21(self):
        """Test case for get_stat_data_raw_data21

        """
        pass

    def test_get_stat_data_raw_data_as_csv22(self):
        """Test case for get_stat_data_raw_data_as_csv22

        """
        pass

    def test_get_stat_query_fields24(self):
        """Test case for get_stat_query_fields24

        """
        pass

    def test_get_stats_raw_data22(self):
        """Test case for get_stats_raw_data22

        """
        pass


if __name__ == '__main__':
    unittest.main()
